%% THIS FUNCTION PLOTS MEDIAN IRFS AND CI

function plotIRF1shock(allIRs, CIperc, s_loc, save_string)
%% s_loc denotes which shock to plot
clear legend;

%% DEFINE PERIOD TO PLOT
IRhoriz 	= size(allIRs,1);	% Length of IRF
irflength 	= 25;			% Length of IRF to plot
t 			= 0:irflength-1;

%% GET LOWER, MEDIAN AND UPPER VARIABLES OF INTEREST FROM SIMULATED DISTRIBUTION
%% IRFS
for hh=1:size(allIRs,1);
    for ii=1:size(allIRs,2);
        for jj=1:size(allIRs,3);
            sliceloc   =  squeeze(allIRs(hh,ii,jj,:));
            IRpercsloc = quantile(sliceloc,[CIperc(1);0.5;CIperc(2)]);
            IRlo(hh,ii,jj)   = IRpercsloc(1);
			IRmed(hh,ii,jj)  = IRpercsloc(2);
            IRup(hh,ii,jj)   = IRpercsloc(3);
        end
    end
end

figure(1);
subplot(3, 2, 1);
hold on;
jbfill(t, IRlo(1:irflength,1,s_loc)',IRup(1:irflength,1,s_loc)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,IRmed(1:irflength,1,s_loc),'-b','LineWidth',3);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 1); 
title('WTI Prices','FontSize',16);xlim([t(1) t(end)]);set(gca,'XTick',t(1:3:end),'FontSize',12);
ylabel('Percent','FontSize',12);
box on; grid on;
set(gca, 'Layer', 'top','GridLineStyle',':','GridColor',[.4, .4, .4],'GridAlpha',1)

subplot(3, 2, 2);
hold on
jbfill(t,IRlo(1:irflength,2,s_loc)',IRup(1:irflength,2,s_loc)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,IRmed(1:irflength,2,s_loc),'-b','LineWidth',3);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 1); 
title('Import Prices','FontSize',16);xlim([t(1) t(end)]);set(gca,'XTick',t(1:3:end),'FontSize',12);
ylabel('Percent','FontSize',12);
box on; grid on;
set(gca, 'Layer', 'top','GridLineStyle',':','GridColor',[.4, .4, .4],'GridAlpha',1)

subplot(3,2,3)
hold on
jbfill(t,IRlo(1:irflength,3,s_loc)',IRup(1:irflength,3,s_loc)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,IRmed(1:irflength,3,s_loc),'-b','LineWidth',3);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 1); 
title('Shipping Costs','FontSize',16);xlim([t(1) t(end)]);set(gca,'XTick',t(1:3:end),'FontSize',12);
ylabel('Percent','FontSize',12);
box on; grid on;
set(gca, 'Layer', 'top','GridLineStyle',':','GridColor',[.4, .4, .4],'GridAlpha',1)

subplot(3,2,4)
hold on
jbfill(t,IRlo(1:irflength,4,s_loc)',IRup(1:irflength,4,s_loc)',[.8, .8, .8],[1 1 1],0,0.6);
plot(t,IRmed(1:irflength,4,s_loc),'-b','LineWidth',3);
plot(t,zeros(irflength,1), '-k', 'LineWidth', 1); 
title('Core PCE Price Level','FontSize',16);xlim([t(1) t(end)]);set(gca,'XTick',t(1:3:end),'FontSize',12);
ylabel('Percent','FontSize',12);
box on; grid on;
set(gca, 'Layer', 'top','GridLineStyle',':','GridColor',[.4, .4, .4],'GridAlpha',1)


%% save to PDF
set(gcf, 'renderer', 'painters');
set(gcf, 'PaperPositionMode', 'manual');
set(gcf, 'PaperUnits', 'inches');
set(gcf, 'PaperOrientation', 'portrait');
set(gcf, 'PaperPosition', [-0.3 -0.7 9.5 12.0]);
print([save_string,'.pdf'],'-dpdf')