%%-- prints a (2 x 3) table to the matlab console
%--
%--					5% shock to Harpex		15% shock 	25% shock
%--	1-year IRF 				.					.			.
%-- 2-year IRF				.					.			.
%--
%--

%-- note:
%--		* the `sample` and `vintage` variables should be set in `var_setup.m`
%-- 	* the `IHoriz` variable in `var_setup.m` needs to be increased to 24
%-- 		before this script is ran



%-- shock sizes, in percent terms
shock_sizes = [5, 15, 25];


year1_response = zeros(length(shock_sizes), 1);
year2_response = zeros(length(shock_sizes), 1);

% harpex is ordered third; cpce is ordered fourth
harpex_loc 	= 3;
cpce_loc 	= 4;

for shock_i = 1:length(shock_sizes)

	shock_size 			= shock_sizes(shock_i);
	immediate_shock 	= IRpoint(1,s_loc,s_loc);
	pred_price_level 	= (shock_size/immediate_shock)*IRpoint(:,cpce_loc,harpex_loc);

	% percent deviation -> basis point space
	year1_response(shock_i, 1) 	= 100 * pred_price_level(12);
	year2_response(shock_i, 1) 	= 100 * (pred_price_level(24) - pred_price_level(12));

end


disp('          							| Effects of Harpex Shock on Core PCE Inflation	|');
disp('          							|-----------------------------------------------|');
disp('          							|     5% Shock      15% Shock      25% Shock  	|');
disp('------------------------------------|-----------------------------------------------|');
fprintf('YoY Inflation After 1-Year  (bps)   |	   %2.3f          %2.3f        %2.3f   	|\n', year1_response);
fprintf('YoY Inflation After 2-Years (bps)   |	   %2.3f          %2.3f         %2.3f  	|\n', year2_response);