%% Structural VAR

%% add auxiliary files to path, load data
cwd = pwd;
cwd = strjoin({cwd, 'VARAuxiliaryFiles'}, '\');
addpath(cwd);


%% SELECT SAMPLE AND PCE VINTAGE
%-- `sample` values:
%-- 	replication: Jan 1, 2001 - Sep 1, 2016
%-- 	full_sample: Jan 1, 2001 - Aug 1, 2021. harpex and wti have september 2021
%--			observations but PCE and imports data haven't been released yet
%--
%-- `vintage` values:
%-- 	latest: uses the Core PCE index as of the September 2021 data release
%-- 	oct16 : uses the Core PCE index as of the October 2016 data release
sample 	= 'replication';
vintage = 'oct16';

if strcmp(sample, 'replication')
	final_date = datetime(2016, 9, 1);

elseif strcmp(sample, 'full_sample')
	final_date = datetime(2021, 8, 1);

else
	error('Unrecognized value for `sample`: %s', sample)

end
first_date 	= datetime(2001, 1, 1);

%-- load data based on `sample` and `vintage` values
load_data;
Y = [wti imports harpex cpce];
Y = Y(find(dates == first_date):find(dates == final_date), :);


%-- check workspace for shock_size variable that might have been set in
%-- 	the `print_table.m` script. if `var_setup.m` is the main script,
%--		default to 5% shock
if exist('shock_size', 'var') == 0
	shock_size 	= 5;
	plot_irfs 	= 1;
else
	plot_irfs 	= 0;
end


%% SET LAG LENGTH
vlag = 3;


%% ESTIMATE WITH CONSTANT BUT NO OTHER CONTROLS
iscon = 1;
isexo = []; %% NO EXOGENOUS CONTROLS IN VAR


%% NOW ESTIMATE
[Bcomp, cvec, dvec, Bpl_ev, VC_eps, Residmat] = ...
									estim_exo(Y, vlag, iscon, isexo);


%% SET NUMBER OF IRF PERIODS
%-- (adds first period so 11 implies 12 periods will be computed)
IRhoriz = 24;



% Uninformative priors
Nbig 	= size(Y, 2);
A_prior = zeros(iscon+size(isexo,2)+Nbig*vlag, Nbig);   
a_prior = A_prior(:);
V_prior = 1e12*eye(iscon+size(isexo,2)+Nbig*vlag);

% Hyperparameters on inv(SIGMA) ~ W(v_prior,inv(S_prior))
v_prior = 0;
S_prior = 0 * eye(Nbig);

% %% SET OPTIONS FOR CONFIDENCE BANDS
%-- monte carlo integration of confidence bands, see Koop and Korobilis, 2010
NMC    		= 10000;				% NUMBER OF DRAWS FROM THE POSTERIOR DISTRIBUTION
CIperc 		= [0.16, 0.84];			% CHOOSE WHICH PERCENTILES TO PLOT
expl   		= 1;					% 0 ACCEPTS EXPLOSIVE DRAWS, 1 REJECTS EXPLOSIVE DRAWS
[IRpoint, allIRs, VARshocks] = ...
	confid_int_exo(Bcomp, VC_eps, cvec, isexo, IRhoriz, NMC, Y, expl, ...
					A_prior, a_prior, V_prior, v_prior, S_prior);


%-- shock location. harpex was ordered 3rd in VAR
s_loc = 3;

%-- rescale all IRFs
immediate_shock = IRpoint(1,s_loc,s_loc);
IRpoint 		= (shock_size/immediate_shock) * IRpoint;
allIRs 			= (shock_size/immediate_shock) * allIRs;



%% PLOT IRF OF INTEREST (Figure 2)
if plot_irfs == 1
	output_filename = 'harpex_shock';
	plotIRF1shock(allIRs, CIperc, s_loc, output_filename)
end

%% PRINT OUTPUT TABLE TO SCREEN (Figure 3)
print_table